@@ -1,12 +1,13 @@
 CREATE TABLE meta
 (
-    id    INTEGER PRIMARY KEY AUTOINCREMENT,
+    id    INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
     key   VARCHAR NOT NULL,
-    value VARCHAR NOT NULL
+    value VARCHAR NOT NULL,
+    UNIQUE(key)
 );
 
 INSERT INTO meta (key, value)
-VALUES ('version', '0.1.0');
+VALUES ('VERSION', '0');
 
 CREATE TABLE files
 (
