@@ -222,12 +222,12 @@ impl UpEndConnection {
             .unwrap())
     }
 
-    pub fn retrieve_file(&self, obj_hash: Hash) -> Result<Vec<models::OutFile>> {
+    pub fn retrieve_file(&self, obj_hash: &Hash) -> Result<Vec<models::OutFile>> {
         use crate::database::inner::schema::files::dsl::*;
 
         let matches = files
             .filter(valid.eq(true))
-            .filter(hash.eq(obj_hash.0))
+            .filter(hash.eq(&obj_hash.0))
             .load::<models::File>(&self.conn)?;
 
         let matches = matches
